==> 3.5.12-core.tar: kdesdk/kbabel/catalogmanager/libsvn/svnhandler.h <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2002-2003 by Marco Wegner <mail@marcowegner.de>
  Copyright (C) 2005, 2006 by Nicolas GOUTTE <goutte@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the Qt library by Trolltech AS, Norway (or with modified versions
  of Qt that use the same license as Qt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  Qt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.
	  
**************************************************************************** */


#ifndef SVNHANDLER_H
#define SVNHANDLER_H

// Qt include files
#include <tqmap.h>
#include <tqobject.h>
// Project specific include files
#include "svndialog.h"
#include "svnresources.h"
// Forwarding Qt classes
class TQString;
class TQStringList;

class KSharedConfig;

/**
 * This class is the backend for SVN support in Catalog Manager.
 *
 * @short  Backend for SVN support in Catalog Manager
 */
class SVNHandler : public QObject
{
  Q_OBJECT

  public:
    enum FileStatus {
      NO_REPOSITORY,
      NOT_IN_SVN,
      LOCALLY_ADDED,
      LOCALLY_REMOVED,
      LOCALLY_MODIFIED,
      CONFLICT,
      UP_TO_DATE,
      ERROR_IN_WC ///< The working copy has data that cannot be handled
    };

    SVNHandler( const TQString& poBaseDir = TQString::null, const TQString& potBaseDir = TQString::null );

    void setPOBaseDir( const TQString& dir );
    void setPOTBaseDir( const TQString& dir );

    FileStatus fstatus( const TQString& filename ) const;
    TQString fileStatus( const FileStatus status ) const;
    TQString svnStatus( const TQString& filename ) const;

    void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config );
    void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config );

    void setAutoUpdateTemplates( bool update );

    /**
     * True if the file was modified or has another status considered as a modification
     */
    bool isConsideredModified( const FileStatus status ) const;

  signals:
    void signalIsPORepository( bool );
    void signalIsPOTRepository( bool );
    void signalFilesCommitted( const TQStringList& );

  private:
      void showDialog( TQWidget* parent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config );
    /// Check quickly if the file is part of a SVN repository
    bool isInSvn( const TQString& path );
    void checkToAdd( const TQStringList& files );
    void processStatusOutput( const TQString& status );
    void processDiff( TQString output );

  private:
    TQString _poBaseDir;
    TQString _potBaseDir;
    bool _isPORepository;
    bool _isPOTRepository;
    bool _autoUpdateTemplates;
    TQString _addCommand;

    /** Mapping the output of 'svn status' against the filename. */
    TQMap<TQString,TQString> map;
};

class SVNOutputCollector: public QObject
{
  Q_OBJECT

 public:
  SVNOutputCollector( KProcess* );
  void setProcess( KProcess* );

  const TQString& getOutput() const { return m_gatheredOutput; }
  const TQString& getStderr() const { return m_stderrOutput; }
  const TQString& getStdout() const { return m_stdoutOutput; }

 private slots:
  void slotGatherStderr( KProcess*, char*, int );
  void slotGatherStdout( KProcess*, char*, int );

 private:
  TQString m_gatheredOutput;
  TQString m_stderrOutput;
  TQString m_stdoutOutput;
  KProcess* m_process;
};

#endif // SVNHANDLER_H

==> 3.5.13-core.tar: kdesdk/kbabel/catalogmanager/libsvn/svnhandler.h <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2002-2003 by Marco Wegner <mail@marcowegner.de>
  Copyright (C) 2005, 2006 by Nicolas GOUTTE <goutte@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.
	  
**************************************************************************** */


#ifndef SVNHANDLER_H
#define SVNHANDLER_H

// TQt include files
#include <tqmap.h>
#include <tqobject.h>
// Project specific include files
#include "svndialog.h"
#include "svnresources.h"
// Forwarding TQt classes
class TQString;
class TQStringList;

class KSharedConfig;

/**
 * This class is the backend for SVN support in Catalog Manager.
 *
 * @short  Backend for SVN support in Catalog Manager
 */
class SVNHandler : public TQObject
{
  Q_OBJECT
  TQ_OBJECT

  public:
    enum FiletqStatus {
      NO_REPOSITORY,
      NOT_IN_SVN,
      LOCALLY_ADDED,
      LOCALLY_REMOVED,
      LOCALLY_MODIFIED,
      CONFLICT,
      UP_TO_DATE,
      ERROR_IN_WC ///< The working copy has data that cannot be handled
    };

    SVNHandler( const TQString& poBaseDir = TQString(), const TQString& potBaseDir = TQString() );

    void setPOBaseDir( const TQString& dir );
    void setPOTBaseDir( const TQString& dir );

    FiletqStatus fstatus( const TQString& filename ) const;
    TQString filetqStatus( const FiletqStatus status ) const;
    TQString svntqStatus( const TQString& filename ) const;

    void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config );
    void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config );

    void setAutoUpdateTemplates( bool update );

    /**
     * True if the file was modified or has another status considered as a modification
     */
    bool isConsideredModified( const FiletqStatus status ) const;

  signals:
    void signalIsPORepository( bool );
    void signalIsPOTRepository( bool );
    void signalFilesCommitted( const TQStringList& );

  private:
      void showDialog( TQWidget* parent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config );
    /// Check quickly if the file is part of a SVN repository
    bool isInSvn( const TQString& path );
    void checkToAdd( const TQStringList& files );
    void processStatusOutput( const TQString& status );
    void processDiff( TQString output );

  private:
    TQString _poBaseDir;
    TQString _potBaseDir;
    bool _isPORepository;
    bool _isPOTRepository;
    bool _autoUpdateTemplates;
    TQString _addCommand;

    /** Mapping the output of 'svn status' against the filename. */
    TQMap<TQString,TQString> map;
};

class SVNOutputCollector: public TQObject
{
  Q_OBJECT
  TQ_OBJECT

 public:
  SVNOutputCollector( KProcess* );
  void setProcess( KProcess* );

  const TQString& getOutput() const { return m_gatheredOutput; }
  const TQString& getStderr() const { return m_stderrOutput; }
  const TQString& getStdout() const { return m_stdoutOutput; }

 private slots:
  void slotGatherStderr( KProcess*, char*, int );
  void slotGatherStdout( KProcess*, char*, int );

 private:
  TQString m_gatheredOutput;
  TQString m_stderrOutput;
  TQString m_stdoutOutput;
  KProcess* m_process;
};

#endif // SVNHANDLER_H
